@@ -7,23 +7,10 @@
 # granted to it by virtue of its status as an intergovernmental organisation
 # nor does it submit to any jurisdiction.
 
-set -eaux
+# set -eaux
 
-for p in netcdf-c[core,netcdf-4,hdf5]
-do
-    echo $p:$WINARCH-windows
-    vcpkg install $p:$WINARCH-windows
-done
+# vcpkg install pango
 
-cd tests
+# find /c/vcpkg -name cairo.h -print
 
-cmake . \
-    -G"NMake Makefiles"  \
-    -DCMAKE_TOOLCHAIN_FILE=/c/vcpkg/scripts/buildsystems/vcpkg.cmake \
-    -DCMAKE_C_COMPILER=cl.exe
-
-cmake --build .
-
-ls -lrt
-
-./open_netcdf test.nc4
+# find /c/vcpkg -name 'pkg-conf*' -print
